spannertools.make_dynamic_spanner_below_with_nib_at_right
=========================================================

.. autofunction:: abjad.tools.spannertools.make_dynamic_spanner_below_with_nib_at_right.make_dynamic_spanner_below_with_nib_at_right
